@@ -202,7 +202,7 @@ def ToList(input):
 _USED_DIRS = set()
 
 def _PyScript(env, target, source, command = "python $SOURCES", 
-                    capture=None, execute=None, *args, **kwargs): 
+                    capture=None, execute=None, tempdir=None, *args, **kwargs): 
     """
     A new Builder added to a scons environment which has the same syntax as Command.
     """
@@ -226,8 +226,40 @@ def _PyScript(env, target, source, command = "python $SOURCES",
     elif capture == "both": command[-1] += " > ${TARGETS[0]} 2> ${TARGETS[1]}"
     elif capture == None: pass
    
-    command = [ env.subst(c, target=target, source=subst) for c in command ]
-    command_sig = command
+    command_sig = [ env.subst(c, target=target, source=subst) for c in command ] 
+
+    basename = None
+    if execute and tempdir == None: 
+        m = hashlib.sha1()
+        m.update(tuple(command_sig))
+        basename = os.path.join("temp", base64.b64encode(m.digest(), "+="), '')
+    else: basename = tempdir
+
+    if env.GetOption("clean") and basename:
+        if os.path.exists(basename): env.Execute(Delete(basename))
+    elif basename:
+        if not os.path.exists(basename): mkdir_p(basename)
+        scons = os.path.join(basename, "SConscript")
+        file = open(scons, 'w')
+        print >>file, """from pyscons import * 
+targets, sources, basename = PySconsSetup()
+PyScript(targets, sources, %s) """ % repr(command)
+        file.close()
+
+        arg = " ".join(["in%g=%s" % (n+1, str(s)) for n,s in enumerate(source)])
+        arg += " " + " ".join(["out%g=%s" % (n+1, str(s)) for n,s in enumerate(target)])
+        vars = " temp=" + basename + " n=" + scons
+
+        exe = os.path.join(basename, "EXECUTE")
+        file = open(exe, 'w')
+        print >>file, "#!/bin/bash\nscons %s -f%s %s $*" % (vars, scons, arg)
+        os.chmod(exe, 0755)
+        file.close()
+
+        command = exe + " -Q"
+
+    if execute: command = execute + " " + basename
+    
 
     gen = lambda source, target, env, for_signature: command_sig if for_signature else command
     return env.Command(target, source, CommandGeneratorAction(gen,{}), *args, **kwargs)
